function plot_individual_orbits(output_data_gei, output_data_geo, currOrbit)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function accepts an input of two matrices and plots various 
% parameters of each.
%
% Inputs: two matrices containing processed Poynting flux data and other
% paramters (output_data_gei, output_data_geo).
%
% Expected format of input matrices:
% output_data_gei(:,1)       = unix time
% output_data_gei(:,2:4)     = alt,lat,long
% output_data_gei(:,5:7)     = delta-B x,y,z (GEI)
% output_data_gei(:,8:10)    = B field x,y,z (GEI)
% output_data_gei(:,11:13)   = E field x,y,z (GEI)
% output_data_gei(:,14)      = Poynting Flux (GEI)
%
% output_data_geo(:,1)       = unix time
% output_data_geo(:,2:4)     = alt,lat,long
% output_data_geo(:,5:7)     = delta-B x,y,z (GEO)
% output_data_geo(:,8:10)    = B field x,y,z (GEO)
% output_data_geo(:,11:13)   = E field x,y,z (GEO)
% output_data_geo(:,14)      = Poynting Flux (GEO)
% output_data_geo(:,15)      = magnetic local time (MLT)
% output_data_geo(:,16)      = invariant latitude (ILAT GEO)

% Convert Unix to MATLAB time and formats time parameters to plot the 
% correct format of the X-Axis (Time)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mtime = unixtime2mat2(output_data_geo(:,1));
startdate =  mtime(1,1);
enddate = mtime(end,1);
timetick = linspace(startdate, enddate, 12);

% Used in the titles of the plots
starttime = datestr(mtime(1)); 
endtime = datestr(mtime(end)); 

%% Plot Poynting Flux vs. Time
figure('name',['Poynting Flux (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,14));
title({['Poynting Flux (GEO) vs. Time: Orbit ' int2str(currOrbit)];[starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('W/m^2');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Poynting Flux (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,14));
title({['Poynting Flux (GEI) vs. Time: Orbit ' int2str(currOrbit)];[starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('W/m^2');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%% Plot Delta-B vs. Time

%GEO
%Subplots
figure('name',['Delta-B (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
subplot(3,1,1);plot(mtime, output_data_geo(:,5));
title({['Delta-B (GEO) vs. Time: Orbit ' int2str(currOrbit)];
     [starttime ' to ' endtime];
     'Delta-B_X (GEO)'}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,2);plot(mtime, output_data_geo(:,6));
title('Delta-B_Y (GEO)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,3);plot(mtime, output_data_geo(:,7));
title('Delta-B_Z (GEO)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%Individual Plots
figure('name',['Delta-B_X (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,5));
title({['Delta-B_X (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); 
xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Delta-B_Y (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,6));
title({['Delta-B_Y (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); 
xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Delta-B_Z (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,7));
title({['Delta-B_Z (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); 
xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%GEI
%Subplots
figure('name',['Delta-B (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
subplot(3,1,1);plot(mtime, output_data_gei(:,5));
title({['Delta-B (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime];
    'Delta-B_X (GEI)'}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,2);plot(mtime, output_data_gei(:,6));
title('Delta-B_Y (GEI)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,3);plot(mtime, output_data_gei(:,7));
title('Delta-B_Z (GEI)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%Individual Plots
figure('name',['Delta-B_X (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,5));
title({['Delta-B_X (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); 
xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Delta-B_Y (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,6));
title({['Delta-B_Y (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); 
xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Delta-B_Z (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,7));
title({['Delta-B_Z (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); 
xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%% Plot Total B (Magnetic Field) vs. Time

%GEO
%Subplots
figure('name',['Magnetic Field (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
subplot(3,1,1);plot(mtime, output_data_geo(:,8));
title({['Magnetic Field (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]; 
    'B_X (GEO)'}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,2);plot(mtime, output_data_geo(:,9));
title('B_Y (GEO)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,3);plot(mtime, output_data_geo(:,10));
title('B_Z (GEO)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%Individual Plots
figure('name',['Magnetic Field_X (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,8));
title({['B_X (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Magnetic Field_Y (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,9));
title({['B_Y (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Magnetic Field_Z (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,10));
title({['B_Z (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%GEI
%Subplots
figure('name',['Magnetic Field (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
subplot(3,1,1);plot(mtime, output_data_gei(:,8));
title({['Magnetic Field (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]; 
    'B_X (GEI)'}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,2);plot(mtime, output_data_gei(:,9));
title('B_Y (GEI)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,3);plot(mtime, output_data_gei(:,10));
title('B_Z (GEI)'); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%Individual Plots
figure('name',['Magnetic Field_X (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,8));
title({['B_X (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Magnetic Field_Y (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,9));
title({['B_Y (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Magnetic Field_Z (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,10));
title({['B_Z (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('Tesla');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%% Plot Electric Field vs. Time

%GEO
%Subplots
figure('name',['Electric Field (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
subplot(3,1,1);plot(mtime, output_data_geo(:,11));
title({['Electric Field (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime];
    'E_X (GEO)'}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,2);plot(mtime, output_data_geo(:,12));
title('E_Y (GEO)'); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,3);plot(mtime, output_data_geo(:,13));
title('E_Z (GEO)'); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%Individual Plots
figure('name',['Electric Field_X (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,11));
title({['Electric Field_X (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Electric Field_Y (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,12));
title({['Electric Field_Y (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Electric Field_Z (GEO) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_geo(:,13));
title({['Electric Field_Z (GEO) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%GEI
%Subplots
figure('name',['Electric Field (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
subplot(3,1,1);plot(mtime, output_data_gei(:,11));
title({['Electric Field (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime];
    'E_X (GEI)'}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,2);plot(mtime, output_data_gei(:,12));
title('E_Y (GEI)'); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');
subplot(3,1,3);plot(mtime, output_data_gei(:,13));
title('E_Z (GEI)'); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

%Individual Plots
figure('name',['Electric Field_X (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,11));
title({['Electric Field_X (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Electric Field_Y (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,12));
title({['Electric Field_Y (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

figure('name',['Electric Field_Z (GEI) vs. Time: Orbit ' int2str(currOrbit)]);
plot(mtime, output_data_gei(:,13));
title({['Electric Field_Z (GEI) vs. Time: Orbit ' int2str(currOrbit)];
    [starttime ' to ' endtime]}); xlabel('Time (UT)'); ylabel('V/m');
grid on; set(gca, 'XTick', timetick); datetick('x','HH:MM', 'keepticks');

end




