function [zin crossings] = zin_for_polar3D(tmp_data, mlt, mlat, dmlt, dmlat, interval)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
% Co-Author: Steven Chen
%
% This function sorts the average Poynting flux intensities into bins based
% on invariant latitude and magnetic local time. It also creates a matrix
% which records the number of orbit crossings which contributed to each bin
% of the Poynting flux averages. These matrices will be used in the
% polar_plot.m function to create the 3D polar plots. 
%
% Input:
% tmp_data - matrix containing the data which will be sorted into the bins
% mlt - starting magnetic local time (limiting parameter)
% mlat - starting invariant latitude (limiting parameter)
% dmlt - ending magnetic local time (limiting parameter)
% dmlat - ending invariant latitude (limiting parameter)
% interval - number of bins that the data will be sorted into
%
% Output: 
% zin - square matrix containing the binned average Poynting flux
% crossing - square matrix containing the contributing number of crossings
% to the zin matrix
%
% Expected format of data in output_data_geo:
% output_data_geo(:,1)       = unix time
% output_data_geo(:,2:4)     = alt,lat,long
% output_data_geo(:,5:7)     = delta-B x,y,z (GEO)
% output_data_geo(:,8:10)    = B field x,y,z (GEO)
% output_data_geo(:,11:13)   = E field x,y,z (GEO)
% output_data_geo(:,14)      = Poynting Flux (GEO)
% output_data_geo(:,15)      = magnetic local time (MLT)
% output_data_geo(:,16)      = invariant latitude (ILAT GEO)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Range of magnetic local time and invariant latitude 
mlt_range = dmlt-mlt;
mlat_range = dmlat-mlat;

% Size of the bins based on the ranges and the inputted desired interval
theta_div = mlt_range/interval;
div_rho = mlat_range/interval;

% Used for comparison reasons when sorting into bins
theta_bin = mlt:theta_div:dmlt;
rho_bin = dmlat:-div_rho:mlat;

% Preallocate space for the square matrices
final = zeros(interval);
count = zeros(interval);
crossings = zeros(interval);

% Directory which data will be read from 
dirlist = dir(tmp_data);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for j = 3:length(dirlist)
    try
        load(strcat(tmp_data,dirlist(j).name)); %load in the first set of data
        data = alt_geo; clearvars alt_geo
        data(any(isnan(data),2),:) = []; %remove all NaNs from data
        cprintf('blue', 'Now processing orbit %d.\n', str2double(dirlist(j).name(1:5)));
        data_rho = data(:,16);    %data_rho = mlat
        data_theta = data(:,15);  %data_theta = mlt
        data_value = data(:,14);  %data_value = Poynting flux

        % Sort data into bins. Record number of crossings into 
        % contributing bins. 
        for rho_row = 1:interval
            for theta_col = 1:interval
                % limit data based on input parameters
                tmp = data_value((theta_bin(theta_col)<data_theta & data_theta<(theta_bin(theta_col)+theta_div))&(rho_bin(rho_row)>data_rho & data_rho>(rho_bin(rho_row)-div_rho)));
                if ~isempty(tmp) % if there is still data after limiting, then bin and average
                    len = length(tmp(:,1));
                    crossings(rho_row, theta_col) = crossings(rho_row, theta_col) + 1; % add data to crossings matrix
                    final(rho_row,theta_col) = final(rho_row,theta_col) + (mean(tmp)*len); % add data to Poynting matrix
                    count(rho_row,theta_col) = count(rho_row,theta_col) + len; % add counts to be used in averaging the Poynting flux
                end
            end
        end
    catch exception
        getReport(exception,'basic', 'hyperlinks', 'off');
        continue       
    end
end

count(count==0)=NaN; % set all bins with 0 counts to NaN
crossings(crossings == 0) = NaN; % set all bins with 0 crossings to NaN
zin = final./count; % divide Poynting matrix by count matrix to get average Poynting flux

% If the desired range is in the Northern hemisphere, invert polar plots
% (used for correcting the orientation of the plots).
if (mlat >= 0 && dmlat >= 0)
   zin = flipud(zin);
   crossings = flipud(crossings);
end

% Delete all files in temporary directory containg data used to create
% binned matrices.
delete(strcat(tmp_data,'*'));


return